@@ -14,7 +14,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 
 sub import {
 	my $class = shift;
@@ -69,8 +69,53 @@ Gnome2::Canvas - (DEPRECATED) A structured graphics canvas
 
   Gtk2->main;
 
+=head1 ABSTRACT
+
+B<(DEPRECATED)> A structured graphics canvas
+
 =head1 DESCRIPTION
 
+B<NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE>
+
+This module has been deprecated by the Gtk-Perl project.  This means that the
+module will no longer be updated with security patches, bug fixes, or when
+changes are made in the Perl ABI.  The Git repo for this module has been
+archived (made read-only), it will no longer possible to submit new commits to
+it.  You are more than welcome to ask about this module on the Gtk-Perl
+mailing list, but our priorities going forward will be maintaining Gtk-Perl
+modules that are supported and maintained upstream; this module is neither.
+
+Since this module is licensed under the LGPL v2.1, you may also fork this
+module, if you wish, but you will need to use a different name for it on CPAN,
+and the Gtk-Perl team requests that you use your own resources (mailing list,
+Git repos, bug trackers, etc.) to maintain your fork going forward.
+
+=over
+
+=item *
+
+Perl URL: https://gitlab.gnome.org/GNOME/perl-gnome2-canvas
+
+=item *
+
+Upstream URL: https://gitlab.gnome.org/Archive/libgnomecanvas
+
+=item *
+
+Last upstream version: 2.30.3
+
+=item *
+
+Last upstream release date: 2011-01-31
+
+=item *
+
+Migration path for this module: No upstream replacement
+
+=back
+
+B<NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE>
+
 The Gnome Canvas is an engine for structured graphics that offers a
 rich imaging model, high-performance rendering, and a powerful,
 high level API.  It offers a choice of two rendering back-ends,
