@@ -2,8 +2,7 @@ package CanvasPrimitives;
 use strict;
 use Gnome2::Canvas;
 use Gtk2::Gdk::Keysyms;
-use constant TRUE => 1;
-use constant FALSE => 0;
+use Glib qw(TRUE FALSE);
 use constant M_PI => 3.141529;
 
 sub zoom_changed {
